---
title: Urubu 0.4 and Urubu Quickstart released
layout: page 
date: 2014-05-25
---

Release features: 

- Run `urubu serve` from the top-level project directory. 
- [Programmable file extensions][/manual/structure] for site pages
- Introducing [urubu-quickstart]: a quick way to set up a new Urubu project.



